@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ini-mode" "0.0.8"
+(define-package "ini-mode" "20250103.1901"
   "Major mode for Windows-style ini files."
   '((emacs "24.1"))
   :url "https://github.com/Lindydancer/ini-mode"
